* GLM .

UNIANOVA
  salary  BY gender minority  WITH educ jobtime
  /METHOD = SSTYPE(3)
  /INTERCEPT = INCLUDE
  /SAVE = PRED SRESID COOK
  /PLOT = PROFILE( gender*minority )
  /EMMEANS = TABLES(minority) WITH(educ=MEAN jobtime=MEAN) COMPARE ADJ(LSD)
  /EMMEANS = TABLES(gender) WITH(educ=MEAN jobtime=MEAN) COMPARE ADJ(LSD)
  /PRINT = PARAMETER HOMOGENEITY
  /PLOT = RESIDUALS
  /CRITERIA = ALPHA(.05)
  /DESIGN = educ jobtime minority gender gender*minority educ*gender .

PPLOT
  /VARIABLES=SRE_1
  /NOLOG
  /NOSTANDARDIZE
  /TYPE=Q-Q
  /FRACTION=BLOM
  /TIES=MEAN
  /DIST=NORMAL.

SORT CASES BY
  SRE_1 (D) .

GRAPH
  /SCATTERPLOT(BIVAR)=PRE_1 WITH SRE_1 BY gender
  /MISSING=LISTWISE .

GRAPH
  /SCATTERPLOT(BIVAR)=educ WITH SRE_1 BY gender
  /MISSING=LISTWISE .

GRAPH
  /SCATTERPLOT(BIVAR)=id WITH COO_1
  /MISSING=LISTWISE .

COMPUTE lnsalary = ln(salary) .
EXECUTE .

USE ALL.
COMPUTE filter_$=(COO_1 < 0.04).
VARIABLE LABEL filter_$ 'COO_1 < 0.04 (FILTER)'.
VALUE LABELS filter_$  0 'Not Selected' 1 'Selected'.
FORMAT filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE .

UNIANOVA
  lnsalary  BY gender minority  WITH educ jobtime
  /METHOD = SSTYPE(3)
  /INTERCEPT = INCLUDE
  /SAVE = PRED SRESID COOK
  /PLOT = PROFILE( gender*minority )
  /EMMEANS = TABLES(minority) WITH(educ=MEAN jobtime=MEAN) COMPARE ADJ(LSD)
  /EMMEANS = TABLES(gender) WITH(educ=MEAN jobtime=MEAN) COMPARE ADJ(LSD)
  /PRINT = PARAMETER HOMOGENEITY
  /PLOT = RESIDUALS
  /CRITERIA = ALPHA(.05)
  /DESIGN = educ jobtime minority gender gender*minority educ*gender .

PPLOT
  /VARIABLES=SRE_2
  /NOLOG
  /NOSTANDARDIZE
  /TYPE=Q-Q
  /FRACTION=BLOM
  /TIES=MEAN
  /DIST=NORMAL.

GRAPH
  /SCATTERPLOT(BIVAR)=PRE_2 WITH SRE_2 BY minority
  /MISSING=LISTWISE .

* Linear Mixed Models .

MIXED
  distance  BY gender  WITH age
  /CRITERIA = CIN(95) MXITER(100) MXSTEP(5) SCORING(1)
  SINGULAR(0.000000000001) HCONVERGE(0, ABSOLUTE) LCONVERGE(0, ABSOLUTE)
  PCONVERGE(0.000001, ABSOLUTE)
  /FIXED = age gender age*gender  | SSTYPE(3)
  /METHOD = REML
  /PRINT = SOLUTION TESTCOV
  /RANDOM INTERCEPT age  | SUBJECT(subject) COVTYPE(UN)
  /REPEATED = age | SUBJECT(subject) COVTYPE(AR1)
  /SAVE = PRED RESID
  /EMMEANS = TABLES(gender) COMPARE ADJ(LSD)  .

* Likelihood ratio test 1.

MIXED
  distance  BY gender  WITH age
  /CRITERIA = CIN(95) MXITER(100) MXSTEP(5) SCORING(1)
  SINGULAR(0.000000000001) HCONVERGE(0, ABSOLUTE) LCONVERGE(0, ABSOLUTE)
  PCONVERGE(0.000001, ABSOLUTE)
  /FIXED = age gender age*gender  | SSTYPE(3)
  /METHOD = REML
  /PRINT = SOLUTION TESTCOV
  /RANDOM INTERCEPT age  | SUBJECT(subject) COVTYPE(UN)
  /SAVE = PRED RESID
  /EMMEANS = TABLES(gender) COMPARE ADJ(LSD)  .

* Likelihood ratio test 2.

MIXED
  distance  BY gender  WITH age
  /CRITERIA = CIN(95) MXITER(100) MXSTEP(5) SCORING(1)
  SINGULAR(0.000000000001) HCONVERGE(0, ABSOLUTE) LCONVERGE(0, ABSOLUTE)
  PCONVERGE(0.000001, ABSOLUTE)
  /FIXED = age gender age*gender  | SSTYPE(3)
  /METHOD = REML
  /PRINT = SOLUTION TESTCOV
  /RANDOM INTERCEPT | SUBJECT(subject) COVTYPE(UN)
  /REPEATED = age | SUBJECT(subject) COVTYPE(AR1)
  /SAVE = PRED RESID
  /EMMEANS = TABLES(gender) COMPARE ADJ(LSD)  .

* Nonparametric tests .

NPAR TEST
  /BINOMIAL (.50)= minority
  /MISSING ANALYSIS.

NPAR TEST
  /CHISQUARE=jobcat
  /EXPECTED=75 10 15
  /MISSING ANALYSIS.

NPAR TESTS
  /M-W= jobtime   BY gender2(1 2)
  /MISSING ANALYSIS.

NPAR TEST
  /SIGN= salary  WITH salbegin (PAIRED)
  /MISSING ANALYSIS.

NPAR TESTS
  /K-W=salary   BY jobcat(1 3)
  /MISSING ANALYSIS.

NPAR TESTS
  /K-S(NORMAL)= salary
  /MISSING ANALYSIS.

* Reliability example .

RELIABILITY
  /VARIABLES=satinform satbestdec satpersvalue satmydec c5r sattime
  satconttxdec
  /SCALE('ALL VARIABLES')  ALL/MODEL=ALPHA.
